import sys
import os
import sys
import json

sys.path.append(os.environ['ANTELOPE'] + "/data/python")

from antelope import stock

class RtWsgiApplication:
    def __init__( self, environ, start_response ):
        self.environ = environ
        self.start_response = start_response

    def __iter__( self ):
        status = '200 OK'
        headers = [('Content-type', 'text/plain')]

        pathparts = self.environ['PATH_INFO'].lstrip('/').split('/')

        if 'QUERY_STRING' in self.environ and len(self.environ['QUERY_STRING']) > 1:
            querydict = dict( x.split('=') for x in self.environ['QUERY_STRING'].split("&") )
        else:
            querydict = {}

        if len(pathparts) != 3:
            status = '404 Not Found'
            body = "Malformed sub-URL '%s'" % self.environ['PATH_INFO']   # SCAFFOLD don't parrot URL in production
        elif pathparts[1] == 'parameterfiles':
            pfname = pathparts[2]
            try:
                pf = stock.pfread(pfname)
                status = '200 OK'
                headers = [('Content-type', 'text/plain')]
                if 'returnformat' not in querydict or querydict['returnformat'] == 'pf':
                    body = pf.pf2string()
                elif querydict['returnformat'] == 'json':
                    body = json.dumps( pf.pf2dict() )
                else:
                    raise ValueError
            except stock.PfReadError:
                status = '404 Not Found'
                body = 'Unable to read parameter-file "' + pfname + '"'
            except ValueError:
                status = '404 Not Found'
                body = 'Unrecognized returnformat "' + querydict['returnformat'] + '"'
        else:
            status = '404 Not Found'
            body = '<p>Unable to find resource "%s"</p>' % pathparts[1]
        

        self.start_response( status, headers )
        yield bytes(body, 'utf-8')
