import os
import tempfile
from datetime import datetime, tzinfo
import pytest
from webservice_fdsn.app.core.station_helpers import db2stationxml_postprocess_raw_xml as xml_postprocessor


io_happy_path_matrix = [((33, 34, -117, -116, datetime(year=2000, month=1, day=1, hour=0,
                                                       minute=0, second=0, tzinfo=None), None),
                         (['AZ', 'PB'], ['RRSP', 'SROS', 'TMSP', 'B082A', 'B086A', 'B088A'])),
                        ((33.6, 34, -146, 180, datetime(year=2000, month=1, day=1, hour=0,
                                                        minute=0, second=0, tzinfo=None), None),
                         (['AZ'], None)),
                        ((33, 34, -116.54, -116.52, datetime(year=2000, month=1, day=1, hour=0,
                                                             minute=0, second=0,
                                                             tzinfo=tzinfo('US/Denver')), None),
                         (['PB'], ['B086A'])),
                        ((33, 34, -117, -116, datetime(year=2013, month=3, day=1, hour=0,
                                                       minute=0, second=0, tzinfo=None),
                          datetime(year=2016, month=12, day=31, hour=0,
                                   minute=0, second=0, tzinfo=tzinfo('US/Denver'))),
                         (['AZ'], ['SROS']))]


@pytest.mark.parametrize("input, output", io_happy_path_matrix)
def test_happy_paths(input, output):
    test_data = os.path.join(os.path.dirname(__file__),
                             os.path.pardir,
                             'test_data',
                             'response_1580448806135.xml')
    with tempfile.NamedTemporaryFile(delete=True,
                                     prefix='dest_', suffix='.xml') as dest_xml:
        _data_found = xml_postprocessor.db2stationxml_filter(test_data,
                                                             dest_xml.name, *input)
        assert _data_found
        assert(os.stat(dest_xml.name).st_size > 0)
        assert(xml_postprocessor.validate_stationxml(dest_xml.name))

        # Validate returned data
        xml_root = xml_postprocessor.get_xml_root(dest_xml.name)
        xml_namespace = xml_postprocessor.get_xml_namespace(xml_root)
        networks = xml_postprocessor.get_networks(xml_root, xml_namespace)
        assert(output[0] == networks)
        if output[1]:
            assert(output[1] == xml_postprocessor.get_stations(xml_root, xml_namespace))


def test_validate_schema():
    """Check if schema validate catches bad xml
    """
    test_data = os.path.join(os.path.dirname(__file__),
                             os.path.pardir,
                             'test_data',
                             'response_1580448806135.xml')
    assert xml_postprocessor.validate_stationxml(test_data)
    assert not (xml_postprocessor.validate_stationxml(
        os.path.join(os.path.dirname(__file__),
                     os.path.pardir,
                     'test_data',
                     'bad_stationxml.xml')))


io_no_data_matrix = [(40, 90, -146, 180,
                      datetime(year=2000, month=1, day=1, hour=0,
                               minute=0, second=0, tzinfo=None)),
                     (33, 34, -110, 180,
                      datetime(year=2000, month=1, day=1, hour=0,
                               minute=0, second=0, tzinfo=None)),
                     (33, 34, -180, 180,
                      datetime(year=2020, month=2, day=1, hour=0,
                               minute=0, second=0, tzinfo=None)),
                     (33, 34, -180, 180,
                      datetime(year=2020, month=2, day=1, hour=0,
                               minute=0, second=0, tzinfo=None),
                      datetime(year=2020, month=2, day=2, hour=0,
                               minute=0, second=0, tzinfo=None))]


@pytest.mark.parametrize("input", io_no_data_matrix)
def test_no_data_paths(input):
    test_data = os.path.join(os.path.dirname(__file__),
                             os.path.pardir,
                             'test_data',
                             'response_1580448806135.xml')
    with tempfile.NamedTemporaryFile(delete=True,
                                     prefix='dest_', suffix='.xml') as dest_xml:
        _data_found = xml_postprocessor.db2stationxml_filter(test_data,
                                                             dest_xml.name, *input)
        assert not _data_found
